summaryrefslogtreecommitdiff
path: root/gdb/gdbarch.h
diff options
context:
space:
mode:
authorUlrich Weigand <uweigand@de.ibm.com>2010-07-06 12:56:21 +0000
committerUlrich Weigand <uweigand@de.ibm.com>2010-07-06 12:56:21 +0000
commitef4ae4726524130b1cc946be6e8df9fb7747f637 (patch)
tree6c6d3cc1d74e1d9b672108e9be280bc3208bf53a /gdb/gdbarch.h
parentd844331d1658deb89d66b7090cb6f4db623cd767 (diff)
downloadgdb-ef4ae4726524130b1cc946be6e8df9fb7747f637.tar.gz
include/ChangeLog:
2010-07-06 Ken Werner <ken.werner@de.ibm.com> * floatformat.h (floatformat_ieee_half_big): Add declaration. (floatformat_ieee_half_little): Likewise. libiberty/ChangeLog: 2010-07-06 Ken Werner <ken.werner@de.ibm.com> * floatformat.c (floatformat_ieee_half_big): New variable. (floatformat_ieee_half_little): Likewise. gdb/ChangeLog: 2010-07-06 Ken Werner <ken.werner@de.ibm.com> * gdbtypes.h (floatformats_ieee_half): Add declaration. * gdbtypes.c (floatformats_ieee_half): New variable. * doublest.c (floatformat_from_length): Set format to gdbarch_half_format if length matches. * gdbarch.sh (half_bit): New architecture method. (half_format): Likewise. * gdbarch.h: Regenerate. * gdbarch.c: Likewise.
Diffstat (limited to 'gdb/gdbarch.h')
-rw-r--r--gdb/gdbarch.h12
1 files changed, 9 insertions, 3 deletions
diff --git a/gdb/gdbarch.h b/gdb/gdbarch.h
index e0c933cb469..cfc777ee1d6 100644
--- a/gdb/gdbarch.h
+++ b/gdb/gdbarch.h
@@ -118,12 +118,18 @@ extern void set_gdbarch_long_bit (struct gdbarch *gdbarch, int long_bit);
extern int gdbarch_long_long_bit (struct gdbarch *gdbarch);
extern void set_gdbarch_long_long_bit (struct gdbarch *gdbarch, int long_long_bit);
-/* The ABI default bit-size and format for "float", "double", and "long
- double". These bit/format pairs should eventually be combined into
- a single object. For the moment, just initialize them as a pair.
+/* The ABI default bit-size and format for "half", "float", "double", and
+ "long double". These bit/format pairs should eventually be combined
+ into a single object. For the moment, just initialize them as a pair.
Each format describes both the big and little endian layouts (if
useful). */
+extern int gdbarch_half_bit (struct gdbarch *gdbarch);
+extern void set_gdbarch_half_bit (struct gdbarch *gdbarch, int half_bit);
+
+extern const struct floatformat ** gdbarch_half_format (struct gdbarch *gdbarch);
+extern void set_gdbarch_half_format (struct gdbarch *gdbarch, const struct floatformat ** half_format);
+
extern int gdbarch_float_bit (struct gdbarch *gdbarch);
extern void set_gdbarch_float_bit (struct gdbarch *gdbarch, int float_bit);